.. hklpy documentation master file

=====
hklpy
=====

.. include:: /substitutions.txt

.. index:: !hklpy

|hklpy| is a Python package for practical use of diffractometers with the
`Bluesky Framework <https://blueskyproject.io>`_.

.. toctree::
   :glob:
   :hidden:

   user_guide
   install
   api
   release_notes

.. icons: https://fonts.google.com/icons

.. grid:: 2

    .. grid-item-card:: :material-outlined:`summarize;3em` :ref:`user_guide`

      How to use |hklpy|

    .. grid-item-card:: :material-regular:`install_desktop;3em` :ref:`install`

      How to install |hklpy|

    .. grid-item-card:: :material-regular:`subscriptions;3em` :ref:`api_documentation`

      About the underlying devices and other support.

    .. grid-item-card:: :material-regular:`history;3em` :ref:`release_notes`

      History of changes.

.. _about:

About
-----

:home: https://blueskyproject.io/hklpy
:source: https://github.com/bluesky/hklpy
:license: :ref:`license`
:full version: |release|
:published: |today|
:index: :ref:`genindex`
:module: :ref:`modindex`
